@@ -1,5 +1,6 @@
 import json
 import os
+import pkgutil
 import re
 import time
 
@@ -7,29 +8,22 @@ import requests
 from bs4 import BeautifulSoup
 
 
-def get_wfcd_api(rebuild=False):
-    if os.path.isfile('wfcd_api.json') and not rebuild:
-        with open('wfcd_api.json') as f:
-            return json.load(f)
-    else:
-        wfcd_api = requests.get(
-            "https://raw.githubusercontent.com/WFCD/warframe-items/master/data/json/All.json").json()
+def get_wfcd_api():
+    wfcd_api = requests.get(
+        "https://raw.githubusercontent.com/WFCD/warframe-items/master/data/json/All.json").json()
 
-        wfcd_api_parsed = {}
+    wfcd_api_parsed = {}
 
-        for item in wfcd_api:
-            wfcd_api_parsed[item['name']] = item
-            if 'components' in wfcd_api_parsed[item['name']]:
-                component_dict = {}
-                for component in wfcd_api_parsed[item['name']]['components']:
-                    component_dict[component['name']] = component
+    for item in wfcd_api:
+        wfcd_api_parsed[item['name']] = item
+        if 'components' in wfcd_api_parsed[item['name']]:
+            component_dict = {}
+            for component in wfcd_api_parsed[item['name']]['components']:
+                component_dict[component['name']] = component
 
-                wfcd_api_parsed[item['name']]['components'] = component_dict
+            wfcd_api_parsed[item['name']]['components'] = component_dict
 
-        with open('wfcd_api.json', 'w') as fp:
-            json.dump(wfcd_api_parsed, fp, indent=4)
-
-        return wfcd_api_parsed
+    return wfcd_api_parsed
 
 
 def fix_name(item_name):
@@ -125,9 +119,10 @@ def required_info(item_name, wfcd_api):
 
 
 def get_relic_list(rebuild=False):
-    if os.path.isfile('relic_list.json') and not rebuild:
-        with open('relic_list.json') as f:
-            return json.load(f)
+    if not rebuild:
+        data = pkgutil.get_data(__name__, "relic_list.json")
+        relic_list = json.loads(data)
+        return relic_list
     else:
         url = 'https://n8k6e2y6.ssl.hwcdn.net/repos/hnfvc0o3jnfvc873njb03enrf56.html'
 
@@ -209,9 +204,6 @@ def get_relic_list(rebuild=False):
         for i in range(0, 5):
             relic_list.popitem()
 
-        with open('relic_list.json', 'w') as fp:
-            json.dump(relic_list, fp, indent=4)
-
         return relic_list
 
 
@@ -264,9 +256,10 @@ def access_info(set):
 
 
 def get_set_data(rebuild=False):
-    if os.path.isfile('set_data.json') and not rebuild:
-        with open('set_data.json') as f:
-            return json.load(f)
+    if not rebuild:
+        data = pkgutil.get_data(__name__, "set_data.json")
+        set_data = json.loads(data)
+        return set_data
     else:
         # List of prime parts
         part_list = []
@@ -274,7 +267,7 @@ def get_set_data(rebuild=False):
         # List of prime sets
         set_list = []
 
-        relic_list = get_relic_list()
+        relic_list = get_relic_list(True)
         wfcd_api = get_wfcd_api()
 
         for relic in relic_list:
@@ -314,9 +307,6 @@ def get_set_data(rebuild=False):
             set_data[set_list[i][0]]['plat'] = price_info(set_list[i][0] + "_set")
             set_data[set_list[i][0]]['prime-access'] = access_info(set_list[i][0])
 
-        with open('set_data.json', 'w') as fp:
-            json.dump(set_data, fp, indent=4)
-
         return set_data
 
 
@@ -397,54 +387,55 @@ def get_average_return(relic):
     return relic
 
 
-def get_relic_data(rebuild=False):
-    # Opens the relic list json and stores it as relic_list
-    if os.path.isfile('relic_data.json') and not rebuild:
-        with open('relic_data.json') as f:
-            relic_data = json.load(f)
-    else:
-        relic_data = get_relic_list()
-        set_data = get_set_data()
-        for relic in relic_data:
-            for refinement in relic_data[relic]:
-                for part in relic_data[relic][refinement]['drops']:
-                    if "Forma" not in part:
-                        relic_data[relic][refinement]['drops'][part]['price'] = \
-                            set_data[get_set_name(part)]['parts'][part]['plat']
+def update_relic_data(relic_data, set_data):
+    for relic in relic_data:
+        for refinement in relic_data[relic]:
+            for part in relic_data[relic][refinement]['drops']:
+                if "Forma" not in part:
+                    relic_data[relic][refinement]['drops'][part]['price'] = \
+                        set_data[get_set_name(part)]['parts'][part]['plat']
 
-                        relic_data[relic][refinement]['drops'][part]['ducats'] = \
-                            set_data[get_set_name(part)]['parts'][part]['ducats']
-                    else:
-                        relic_data[relic][refinement]['drops'][part]['price'] = 0
-                        relic_data[relic][refinement]['drops'][part]['ducats'] = 0
+                    relic_data[relic][refinement]['drops'][part]['ducats'] = \
+                        set_data[get_set_name(part)]['parts'][part]['ducats']
+                else:
+                    relic_data[relic][refinement]['drops'][part]['price'] = 0
+                    relic_data[relic][refinement]['drops'][part]['ducats'] = 0
 
-                    relic_data[relic][refinement]['drops'][part]['calculated_chance'] = \
-                        {"solo": relic_data[relic][refinement]['drops'][part]['chance'],
-                         "1b1": relic_data[relic][refinement]['drops'][part]['chance'] * 4}
+                relic_data[relic][refinement]['drops'][part]['calculated_chance'] = \
+                    {"solo": relic_data[relic][refinement]['drops'][part]['chance'],
+                     "1b1": relic_data[relic][refinement]['drops'][part]['chance'] * 4}
 
-                    relic_data[relic][refinement]['drops'][part]['calculated_price'] = \
-                        {"solo": relic_data[relic][refinement]['drops'][part]['price'] *
-                                 relic_data[relic][refinement]['drops'][part]['chance'],
-                         "1b1": relic_data[relic][refinement]['drops'][part]['price'] *
-                                relic_data[relic][refinement]['drops'][part]['chance'] * 4}
-                relic_data[relic][refinement]['average_return'] = {}
-                relic_data[relic][refinement] = get_average_return(relic_data[relic][refinement])
-
-        with open('relic_data.json', 'w') as fp:
-            json.dump(relic_data, fp, indent=4)
+                relic_data[relic][refinement]['drops'][part]['calculated_price'] = \
+                    {"solo": relic_data[relic][refinement]['drops'][part]['price'] *
+                             relic_data[relic][refinement]['drops'][part]['chance'],
+                     "1b1": relic_data[relic][refinement]['drops'][part]['price'] *
+                            relic_data[relic][refinement]['drops'][part]['chance'] * 4}
+            relic_data[relic][refinement]['average_return'] = {}
+            relic_data[relic][refinement] = get_average_return(relic_data[relic][refinement])
 
     return relic_data
 
 
-def update_prices_and_averages():
-    set_data = get_set_data()
+def get_relic_data(rebuild=False):
+    if not rebuild:
+        data = pkgutil.get_data(__name__, "relic_data.json")
+        relic_data = json.loads(data)
+        return relic_data
+    else:
+        relic_data = get_relic_list(True)
+        set_data = get_set_data(True)
+        relic_data = update_relic_data(relic_data, set_data)
+
+    return relic_data
+
+
+def update_prices_and_averages(set_data, relic_data):
     for prime_set in set_data:
         set_data[prime_set]['plat'] = price_info(prime_set + "_set")
 
         for part in set_data[prime_set]['parts']:
             set_data[prime_set]['parts'][part]['plat'] = price_info(fix_name(part))
 
-    with open('set_data.json', 'w') as fp:
-        json.dump(set_data, fp, indent=4)
+    relic_data = update_relic_data(relic_data, set_data)
 
-    get_relic_data(True)
+    return set_data, relic_data
